#!/tmp/build/80754af9/gdal-split_1622391789908/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_pla/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.0.2','gdal_sieve.py'
__requires__ = 'GDAL==3.0.2'
__import__('pkg_resources').run_script('GDAL==3.0.2', 'gdal_sieve.py')
